@@ -219,37 +219,6 @@ def integrate_path(fwdfilename, bkdfilename, nelements=1, concentration=[1,], us
         fdui, fdur, flambda = np.loadtxt(fwdfilename, unpack=True, comments="#", usecols=usecols)
         bdui, bdur, blambda = np.loadtxt(bkdfilename, unpack=True, comments="#", usecols=usecols)
 
-    #SOLID HAS NO ISSUES - NO SCALING NEEDED
-    #THIS IS TEMPORARY
-    #UFM ENERGY IS NOT SCALED IN LAMMPS-THIS IS WRONG! BUT UNTIL THEN, WE KEEP THIS
-    if not solid:
-            #now scale with lambda
-            # What happens here?
-            # - Solid is not affected because fix/adapt is not used
-            # - Liquid : UFM system energy is not scaled with fix:adapt (this is actually wrong, but works for us)
-            # - Liquid : So we only unscale the system of interest in liquid
-            # - Alchemy : Both system energies are scaled with fix:adapt, so we need to unscale both
-            #for i in range(len(fdui)):
-            #    if flambda[i] !=0:
-            #        fdui[i] = fdui[i]/flambda[i]
-            #for i in range(len(bdui)):
-            #    if blambda[i] !=0:
-            #        bdui[i] = bdui[i]/blambda[i]
-
-            if alchemy:
-                """
-                This is the unscaling happening here - ideally when liquid ufm is fixed, this will not
-                just be for alchemy, but for all non solid calculations
-                """
-                #this for the ref system : so forward and backard lambdas are reversed!
-                for i in range(len(fdur)):
-                    if blambda[i] !=0:
-                        fdur[i] = fdur[i]/blambda[i]
-                for i in range(len(bdur)):
-                    if flambda[i] !=0:
-                        bdur[i] = bdur[i]/flambda[i]
-            
-
     fdu = fdui - fdur
     bdu = bdui - bdur
     
